<%@ Page Language="C#" AutoEventWireup="true" ValidateRequest="false" Debug="true" %>

<%@ Import Namespace="System.IO" %>
<%@ Import Namespace="System.Xml" %>

<script runat="server">
	//This variable specifies relative path to the folder, where the gallery with uploaded files is located.
	//Do not forget about the slash in the end of the folder name.
	private string galleryPath = "../Gallery/";

	private void Page_Load(System.Object sender, System.EventArgs e)
	{
		//First of all, clear data uploaded at previous time.

		//Delete source files
		DirectoryInfo dir = new DirectoryInfo(Server.MapPath(galleryPath));
		foreach (FileInfo file in dir.GetFiles())
		{
			file.Delete();
		}

		//Delete thumbnails
		dir = new DirectoryInfo(Server.MapPath(galleryPath) + "/Thumbnails");
		foreach (FileInfo file in dir.GetFiles())
		{
			file.Delete();
		}

		//NOTE: If you do not want to delete previously uploaded files, just 
		//remove or comment out the code above.

		//Create XML file which will keep information about files (image dimensions, description, etc). 
		//XML is used solely for brevity. In real-life application most likely you will use database instead.
		XmlDocument descriptions = new XmlDocument();
		descriptions.AppendChild(descriptions.CreateElement("files"));

		//Get total number of uploaded files (all files are uploaded in a single package).
		int fileCount = Int32.Parse(Request.Form["FileCount"]);

		//This value will keep a total size of actually uploaded images. It will be displayed
		//so that you could compare how many bytes you save. 
		long totalUploadedFileSize = 0;

		//Iterate through uploaded data and save the large and small thumbnails.
		for (int i = 1; i <= fileCount; i++)
		{
			//Get the first thumbnail and save it to disk. It stores 1200x1200 optimized image.
			HttpPostedFile thumbnail1File = Request.Files["Thumbnail1_" + i];
			string fileName = GetSafeFileName(Path.GetFileName(Request.Form["FileName_" + i]));
			thumbnail1File.SaveAs(Server.MapPath(galleryPath + fileName));

			totalUploadedFileSize += thumbnail1File.InputStream.Length;

			//Get the second thumbnail and save it to disk. It stores 120x120 preview image. 
			HttpPostedFile thumbnail2File = Request.Files["Thumbnail2_" + i];
			thumbnail2File.SaveAs(Server.MapPath(galleryPath + "Thumbnails/" + fileName + ".jpg"));

			//Save file info.
			XmlElement xmlFile = descriptions.CreateElement("file");
			xmlFile.SetAttribute("name", fileName);
			xmlFile.SetAttribute("width", Request.Form["Width_" + i]);
			xmlFile.SetAttribute("height", Request.Form["Height_" + i]);

			descriptions.DocumentElement.AppendChild(xmlFile);
		}

		//Write both optimized and source file sizes for comparison.
		descriptions.DocumentElement.SetAttribute("totalSourceFileSize", Request.Form["TotalSourceFileSize"]);
		descriptions.DocumentElement.SetAttribute("totalUploadedFileSize", Convert.ToString(Math.Ceiling((double)(totalUploadedFileSize / 1024))));

		//Save the description XML file.
		descriptions.Save(Server.MapPath(galleryPath + "Descriptions.xml"));
	}

	//This method verifies whether file with such name already exists 
	//and if so, construct safe filename name (to avoid collision).	
	private string GetSafeFileName(string fileName)
	{
		string newFileName = fileName;
		int j = 1;
		while (File.Exists(Server.MapPath(galleryPath + newFileName)))
		{
			newFileName = j + "_" + fileName;
			j++;
		}
		return newFileName;
	}
</script>

