<%@ Page Language="C#" AutoEventWireup="True" Debug="true" ValidateRequest="false" %>

<%@ Import Namespace="System.IO" %>
<%@ Import Namespace="System.Xml" %>

<script runat="server">
	//This variable specifies relative path to the folder, where the gallery with uploaded files is located.
	//Do not forget about the slash in the end of the folder name.
	private string galleryPath = "../Gallery/";

	private void Page_Load(System.Object sender, System.EventArgs e)
	{
		//First of all, clear data uploaded at previous time.

		//In this code sample each file is uploaded with a separate request. It means that this 
		//page will be called for each file individually (rather than once for all files). Therefore
		//we need a way to determine whether this page is called for new upload session or not.
		//
		//To do it we check a PackageIndex POST field which returns a number of the request in the upload session.
		//If it is the very first package we should delete all files and thumbnails we uploaded before. 
		//Otherwise, previously uploaded files belong to the same upload session and we should not delete them.
		int packageIndex = Int32.Parse(Request.Form["PackageIndex"]);

		//If we receive the first file, we delete all files and thumbnails we uploaded before.
		if (packageIndex == 0)
		{
			//Delete source files.
			DirectoryInfo dir = new DirectoryInfo(Server.MapPath(galleryPath));
			foreach (FileInfo file in dir.GetFiles())
			{
				file.Delete();
			}

			//Delete thumbnails.
			dir = new DirectoryInfo(Server.MapPath(galleryPath) + "/Thumbnails");
			foreach (FileInfo file in dir.GetFiles())
			{
				file.Delete();
			}
		}

		//NOTE: If you do not want to delete previously uploaded files, just 
		//remove or comment out the code above.

		//Create XML file which will keep information about files (image dimensions, description, etc).
		//XML is used solely for brevity. In real-life application most likely you will use database instead.
		XmlDocument descriptions = new XmlDocument();

		//If we receive the first file then
		//we start from empty file with descriptions
		if (packageIndex == 0)
		{
			descriptions.AppendChild(descriptions.CreateElement("files"));
		}
		else
		{
			descriptions.Load(Server.MapPath(galleryPath + "Descriptions.xml"));
		}

		//NOTE: Since each file is uploaded in a separate request (because
		//FilesPerOnePackageCount param equals to 1), you should work only
		//with POST fields with index = 1 (such as SourceFile_1, FileName_1, etc).
		HttpPostedFile sourceFile = Request.Files["SourceFile_1"];

		string fileName = GetSafeFileName(sourceFile.FileName);
		sourceFile.SaveAs(Server.MapPath(galleryPath + fileName));

		//Get the thumbnail and save it to disk.
		Request.Files["Thumbnail1_1"].SaveAs(Server.MapPath(galleryPath + "Thumbnails/" + fileName + ".jpg"));

		//Save file info.
		XmlElement xmlFile = descriptions.CreateElement("file");
		xmlFile.SetAttribute("name", fileName);
		xmlFile.SetAttribute("width", Request.Form["Width_1"]);
		xmlFile.SetAttribute("height", Request.Form["Height_1"]);
		xmlFile.SetAttribute("description", Request.Form["Description_1"]);

		descriptions.DocumentElement.AppendChild(xmlFile);

		descriptions.Save(Server.MapPath(galleryPath + "Descriptions.xml"));
	}

	//This method verifies whether file with such name already exists
	//and if so, construct safe filename name (to avoid collision).
	private string GetSafeFileName(string fileName)
	{
		string newFileName = fileName;
		int j = 1;
		while (File.Exists(Server.MapPath(galleryPath + newFileName)))
		{
			newFileName = j + "_" + fileName;
			j++;
		}
		return newFileName;
	}
</script>

