<%@ Page Language="C#" AutoEventWireup="True" %>

<%@ Import Namespace="System.IO" %>
<%@ Import Namespace="System.Xml" %>

<script runat="server">
	//This variable specifies relative path to the folder, where the gallery with uploaded files is located.
	//Do not forget about the slash in the end of the folder name.
	private string galleryPath = "../Gallery/";

	private void Page_Load(System.Object sender, System.EventArgs e)
	{
		//First of all, clear data uploaded at previous time.

		//Delete source files.
		DirectoryInfo dir = new DirectoryInfo(Server.MapPath(galleryPath));
		foreach (FileInfo file in dir.GetFiles())
		{
			file.Delete();
		}

		//Delete thumbnails.
		dir = new DirectoryInfo(Server.MapPath(galleryPath) + "/Thumbnails");
		foreach (FileInfo file in dir.GetFiles())
		{
			file.Delete();
		}

		//NOTE: If you do not want to delete previously uploaded files, just
		//remove or comment out the code above.

		//Create XML file which will keep information about files (image dimensions, description, etc).
		//XML is used solely for brevity. In real-life application most likely you will use database instead.
		XmlDocument descriptions = new XmlDocument();
		descriptions.AppendChild(descriptions.CreateElement("files"));

		//Get total number of uploaded files (all files are uploaded in a single package).
		int fileCount = Int32.Parse(Request.Form["FileCount"]);

		//Iterate through uploaded data and save the original file, thumbnail, and description.
		for (int i = 1; i <= fileCount; i++)
		{
			//Get source file and save it to disk.
			HttpPostedFile sourceFile = Request.Files["SourceFile_" + i];
			string fileName = GetSafeFileName(Path.GetFileName(sourceFile.FileName));

			//In this demo the following imaging operations are applied:
			//  
			//  - If the user rotates the image in Image Uploader, rotate the original file.
			//  - Add a border around the image.
			using (System.Drawing.Bitmap sourceBitmap =
				new System.Drawing.Bitmap(sourceFile.InputStream))
			{
				//Check if user rotated the image and if yes, what is the angle.
				int angle = Int32.Parse(Request.Form["Angle_" + i]);
				switch (angle)
				{
					case 90:
						sourceBitmap.RotateFlip(System.Drawing.RotateFlipType.Rotate90FlipNone);
						break;
					case 180:
						sourceBitmap.RotateFlip(System.Drawing.RotateFlipType.Rotate180FlipNone);
						break;
					case 270:
						sourceBitmap.RotateFlip(System.Drawing.RotateFlipType.Rotate270FlipNone);
						break;
				}

				//Add extra pixels to the image to be able to draw a border.
				using (System.Drawing.Bitmap resultBitmap =
					new System.Drawing.Bitmap(sourceBitmap.Width + 30, sourceBitmap.Height + 30))
				{
					using (System.Drawing.Graphics graphics =
						System.Drawing.Graphics.FromImage(resultBitmap))
					{
						//Fill the image with the border color.
						graphics.FillRectangle(new System.Drawing.SolidBrush(System.Drawing.Color.FromArgb(255, 240, 240, 240)),
							0, 0, sourceBitmap.Width + 30, sourceBitmap.Height + 30);

						//Copy the original image to the center of new image.
						graphics.DrawImage(sourceBitmap, 15, 15, sourceBitmap.Width, sourceBitmap.Height);

						//Draw double border.
						System.Drawing.Pen pen = new System.Drawing.Pen(System.Drawing.Color.Black, 1);

						graphics.DrawRectangle(pen, 13, 13, sourceBitmap.Width + 3, sourceBitmap.Height + 3);
						graphics.DrawRectangle(pen, 10, 10, sourceBitmap.Width + 9, sourceBitmap.Height + 9);

						//Save the result file to disk.
						resultBitmap.Save(Server.MapPath(galleryPath + fileName));
					}
				}
			}

			//Get first thumbnail (the single thumbnail in this code sample) and save it to disk. 
			//NOTE: No imaging operations are applied on the thumbnail. But if you need it, feel 
			//free to modify this code.
			HttpPostedFile thumbnailFile = Request.Files["Thumbnail1_" + i];
			thumbnailFile.SaveAs(Server.MapPath(galleryPath + "Thumbnails/" + fileName + ".jpg"));

			//Save file info.
			XmlElement file = descriptions.CreateElement("file");
			file.SetAttribute("name", fileName);
			file.SetAttribute("width", Request.Form["Width_" + i]);
			file.SetAttribute("height", Request.Form["Height_" + i]);
			file.SetAttribute("description", Request.Form["Description_" + i]);

			descriptions.DocumentElement.AppendChild(file);
		}

		descriptions.Save(Server.MapPath(galleryPath + "Descriptions.xml"));
	}

	//This method verifies whether file with such name already exists 
	//and if so, construct safe filename name (to avoid collision).	
	private string GetSafeFileName(string fileName)
	{
		string newFileName = fileName;
		int j = 1;
		while (File.Exists(Server.MapPath(galleryPath + newFileName)))
		{
			newFileName = j + "_" + fileName;
			j++;
		}
		return newFileName;
	}
</script>

