#!/usr/bin/perl

use CGI qw/:standard/;
use File::Spec;
use File::Basename;
use XML::Simple;

#Modify this block, according to your needs.

#This variable specifies relative path to the folder, where the gallery with uploaded files is located.
#Do not forget about the slash in the end of the folder name.
my $galleryPath = "../Gallery/";
my $absGalleryPath;
my $absThumbnailsPath;

sub print_html {
	print "Content-Type: text/html\r\n\r\n";
	print "\r\n";
}

sub save_uploaded_files {
	#Physical path to the gallery folder
	$absGalleryPath = File::Spec->rel2abs($galleryPath);
	$absThumbnailsPath = File::Spec->join($absGalleryPath, "Thumbnails");
	
	#Get the source file and save it to disk. 
    
	#NOTE: Since each file is uploaded in a separate request (because 
	#FilesPerOnePackageCount param equals to 1), you should work only 
	#with POST fields with index = 1 (such as SourceFile_1, FileName_1, etc). 
	#Get source file and save it to disk.
	my $sourceFilePath = param("SourceFile_1");
	my $fileName = get_safe_file_name($sourceFilePath);
	#Copy file to gallery folder
	open(OUT, ">" . File::Spec->join($absGalleryPath, $fileName)); 
	binmode(OUT);  
	while (<$sourceFilePath>) {   
		print OUT $_;   
	}  
	close(OUT);
	
	#Get the thumbnail and save it to disk.
	my $thumbnail1Path = param("Thumbnail1_1");
	#Copy file to thumbnails folder
	open(OUT, ">" . File::Spec->join($absThumbnailsPath, $fileName . ".jpg")); 
	binmode(OUT);  
	while (<$thumbnail1Path>) {   
		print OUT $_;   
	}  
	close(OUT);

	#Get file info and save it to XML file.
	#NOTE: In this demo this file is used by different upload threads asynchronously. That's why 
	#it is necessary to synchronize access to this file. 
	
	sysopen(LOCK, File::Spec->join($absGalleryPath, "Descriptions.lck"), O_RDWR);
	flock(LOCK, 2);

	my $descriptionsPath = File::Spec->join($absGalleryPath, "Descriptions.xml");

	#Create XML file which will keep information about files (image dimensions, description, etc). 
	#XML is used solely for brevity. In real-life application most likely you will use database instead.
	my @files;
	
	if (-f  $descriptionsPath) {
		my $xml = new XML::Simple(KeyAttr => [], ForceArray => 1);
		my $descriptions = $xml->XMLin($descriptionsPath);
		@files = @{$descriptions->{file}};
	}

	push(@files, {name => $fileName, width => param("Width_1"), 
		height => param("Height_1"), handlerUrl => "blah"});

	my $descriptions = {file => \@files};    	
	my $xml = new XML::Simple(NoAttr => 0, RootName => 'files', OutputFile => $descriptionsPath);  	
	$xml->XMLout($descriptions);

	close(LOCK);
}


#This method verifies whether file with such name already exists 
#and if so, construct safe filename name (to avoid collision).
sub get_safe_file_name {
	my $fileName = basename(shift(@_));	
	my $newFileName = $fileName;
	my $j = 1;
	while (-e File::Spec->join($absGalleryPath, $newFileName)) {
		$newFileName = $j . "_" . $fileName;
	}
	return $newFileName;
}

print_html();

save_uploaded_files();