#!/usr/bin/perl

use CGI qw/:standard/;
use File::Spec;
use File::Basename;
use XML::Simple;

#Modify this block, according to your needs.

#This variable specifies relative path to the folder, where the gallery with uploaded files is located.
#Do not forget about the slash in the end of the folder name.
my $galleryPath = "../Gallery/";
my $absGalleryPath;
my $absThumbnailsPath;

sub print_html {
	print "Content-Type: text/html\r\n\r\n";
	print "\r\n";
}

sub save_uploaded_files {
	#Physical path to the gallery folder
	$absGalleryPath = File::Spec->rel2abs($galleryPath);
	$absThumbnailsPath = File::Spec->join($absGalleryPath, "Thumbnails");
	
	#First of all, clear data uploaded at previous time.
	
	#In this code sample each file is uploaded with a separate request. It means that this 
	#page will be called for each file individually (rather than once for all files). Therefore
	#we need a way to determine whether this page is called for new upload session or not.
	#
	#To do it we check a PackageIndex POST field which returns a number of the request in the upload session.
	#If it is the very first package we should delete all files and thumbnails we uploaded before. 
	#Otherwise, previously uploaded files belong to the same upload session and we should not delete them. 	
	my $packageIndex = param("PackageIndex");
	
	#If we receive the first file, we delete all files and thumbnails we uploaded before.  	
	if ($packageIndex == 0) {
		my $handle;
		
		#Delete source files.
		opendir($handle, $absGalleryPath);
		while (my $fileName = readdir($handle)) {
			my $filePath = File::Spec->join($absGalleryPath, $fileName);
			if (-f $filePath) {
				unlink($filePath);
			}
		}
		closedir($handle);
		
		#Delete thumbnails.
		opendir($handle, $absThumbnailsPath);
		while (my $fileName = readdir($handle)) {
			my $filePath = File::Spec->join($absThumbnailsPath, $fileName);
			if (-f $filePath) {
				unlink($filePath);
			}
		}
		closedir($handle);
	}
	
	#NOTE: If you do not want to delete previously uploaded files, just
	#remove or comment out the code above.

	#Create array (for futher saving in XML file) which will keep information about files (image dimensions, description, etc).
	#XML is used solely for brevity. In real-life application most likely you will use database instead.
	
	my $descriptionsPath = File::Spec->join($absGalleryPath, "Descriptions.xml");
	
	my @files;
	
	#If we receive the first file then #we start from empty array with descriptions, 
	#otherwise we load descriptions from the file
	if ($packageIndex != 0)
	{
		my $xml = new XML::Simple(KeyAttr => [], ForceArray => 1);
		my $descriptions = $xml->XMLin($descriptionsPath);
		@files = @{$descriptions->{file}};
	}
	
	#NOTE: Since each file is uploaded in a separate request (because 
	#FilesPerOnePackageCount param equals to 1), you should work only 
	#with POST fields with index = 1 (such as SourceFile_1, FileName_1, etc). 
	
	#Get source file and save it to disk.
	my $sourceFilePath = param("SourceFile_1");
	my $fileName = get_safe_file_name($sourceFilePath);
	#Copy file to gallery folder
	open(OUT, ">" . File::Spec->join($absGalleryPath, $fileName)); 
	binmode(OUT);  
	while (<$sourceFilePath>) {   
		print OUT $_;   
	}  
	close(OUT);
	
	#Get the thumbnail and save it to disk.
	my $thumbnail1Path = param("Thumbnail1_1");
	#Copy file to thumbnails folder
	open(OUT, ">" . File::Spec->join($absThumbnailsPath, $fileName . ".jpg")); 
	binmode(OUT);  
	while (<$thumbnail1Path>) {   
		print OUT $_;   
	}  
	close(OUT);
	
	#Save file info.
	push(@files, {name => $fileName, width => param("Width_1"), 
		height => param("Height_1"), description => param("Description_1")});
	
	my $descriptions = {file => \@files};    	
	my $xml = new XML::Simple(NoAttr => 0, RootName => 'files', OutputFile => $descriptionsPath);  	
	$xml->XMLout($descriptions);
}

#This method verifies whether file with such name already exists 
#and if so, construct safe filename name (to avoid collision).
sub get_safe_file_name {
	my $fileName = basename(shift(@_));	
	my $newFileName = $fileName;
	my $j = 1;
	while (-e File::Spec->join($absGalleryPath, $newFileName)) {
		$newFileName = $j . "_" . $fileName;
	}
	return $newFileName;
}

print_html();

save_uploaded_files();