#!/usr/local/bin/python

#For image processing we use Python Imaging Library (PIL)
#	http://www.pythonware.com/products/pil/index.htm

import cgi
import cgitb; cgitb.enable()
import os
import xml.dom
import Image
import ImageDraw

try: # Windows needs stdio set for binary mode.
	import msvcrt
	msvcrt.setmode ( 0, os.O_BINARY ) # stdin  = 0
	msvcrt.setmode ( 1, os.O_BINARY ) # stdout = 1
except ImportError:
	pass

#This variable specifies relative path to the folder, where the gallery with uploaded files is located.
#Do not forget about the slash in the end of the folder name.
galleryPath = "../Gallery/"

def print_html ():
	print "Content-Type: text/html"
	print
	print	

def save_uploaded_files ():
	absGalleryPath = os.path.abspath( galleryPath )
	absThumbnailsPath = os.path.join( absGalleryPath, "Thumbnails" )
		
	#First of all, clear files and data uploaded at previous time.
	
	#Delete source files.		
	for fileName in os.listdir( absGalleryPath ):	
		filePath = os.path.join( absGalleryPath, fileName )
		if not os.path.isdir( filePath ):
			os.remove( filePath )
	
	#Delete thumbnails.
	for fileName in os.listdir( absThumbnailsPath ):	
		filePath = os.path.join( absThumbnailsPath, fileName )
		if not os.path.isdir( filePath ):			
			os.remove( filePath )

	#NOTE: If you do not want to delete previously uploaded files, just 
	#remove or comment out the code above.

	#Create XML file which will keep information about files (image dimensions, description, etc). 
	#XML is used solely for brevity. In real-life application most likely you will use database instead.
	domImplementation = xml.dom.getDOMImplementation()
	descriptions = domImplementation.createDocument( "", "files", None )

	form = cgi.FieldStorage()

	#Get total number of uploaded files (all files are uploaded in a single package).
	fileCount = int( form.getfirst( "FileCount", "0" ) );

	#Iterate through uploaded data and save the original file, thumbnail, and description.
	for i in range( 1, fileCount + 1 ):
		#Get source file and save it to disk.
		sourceFile = form["SourceFile_" + str( i )];				
		if not sourceFile.file:
			return
		
		fileName = get_safe_file_name( sourceFile.filename )	
		absSourceFilePath = os.path.join( absGalleryPath, fileName )
		f = open ( absSourceFilePath, 'wb' )
		while 1:
			chunk = sourceFile.file.read( 10000 )
			if not chunk: 
				break	
			f.write( chunk )
		f.close()
		
		#In this demo the following imaging operations are applied:
		#  
		#  - If the user rotates the image in Image Uploader, rotate the original file.
		#  - Add a border around the image.
		#
		
		sourceImage = Image.open( absSourceFilePath )

		#Check if user rotated the image and if yes, what is the angle.
		angle = int( form.getfirst("Angle_" + str(i)) );
		if angle == 90:
			#Image Uploader uses clockwise angle, at that time as
			#transpose method accepts counterclockwise one
			rotatedImage = sourceImage.transpose( Image.ROTATE_270)
		elif angle == 180:
			rotatedImage = sourceImage.transpose( Image.ROTATE_180)
		elif angle == 270:
			#Image Uploader uses clockwise angle, at that time as
			#transpose method accepts counterclockwise one
			rotatedImage = sourceImage.transpose( Image.ROTATE_90)
		else:
			rotatedImage = sourceImage
		
		#Add extra pixels to the image to be able to draw a border.
		#Fill the image with the border color.
		resultImage = Image.new( "RGB", ( rotatedImage.size[0] + 30, rotatedImage.size[1] + 30 ), ( 240, 240, 240 ) )
		
		#Copy the original image to the center of new image.
		resultImage.paste( rotatedImage, ( 15, 15 ) );
		
		#Draw double border.
		draw = ImageDraw.Draw( resultImage )
		draw.rectangle( ( 13, 13, rotatedImage.size[0] + 16, rotatedImage.size[1] + 16 ), fill = None, outline = ( 0, 0, 0 ) );
		draw.rectangle( ( 10, 10, rotatedImage.size[0] + 19, rotatedImage.size[1] + 19 ), fill = None, outline = ( 0, 0, 0 ) );

		#Save the result file to disk.
		resultImage.save( absSourceFilePath, "JPEG", quality=80)

			
		#Get first thumbnail (the single thumbnail in this code sample) and save it to disk.
		#NOTE: No imaging operations are applied on the thumbnail. But if you need it, feel 
		#free to modify this code.
		thumbnail1File = form["Thumbnail1_" + str( i )];
		if not thumbnail1File.file:
			return

		f = open ( os.path.join( absThumbnailsPath, fileName + ".jpg" ), 'wb' )
		while 1:
			chunk = thumbnail1File.file.read( 10000 )
			if not chunk: 
				break	
			f.write( chunk )
		f.close()

		#Save file info.
		xmlFile = descriptions.createElement( "file" )
		xmlFile.setAttribute( "name", fileName )
		xmlFile.setAttribute( "width", form.getfirst( "Width_" + str( i ), "0" ) );
		xmlFile.setAttribute( "height", form.getfirst( "Height_" + str( i ), "0" ) );
		xmlFile.setAttribute( "description", form.getfirst( "Description_" + str( i ), "" ) );
		descriptions.documentElement.appendChild( xmlFile );

	descriptionsFile = open( os.path.join( absGalleryPath, "Descriptions.xml" ), "w" )
	descriptionsFile.write( descriptions.toxml() )
	descriptionsFile.close()

#This method verifies whether file with such name already exists 
#and if so, construct safe filename name (to avoid collision).
def get_safe_file_name( fileName ):
	fileName = os.path.basename( fileName )
	newFileName = fileName
	j = 1
	while os.path.exists( os.path.join( os.path.abspath( galleryPath ), newFileName ) ):
		newFileName = str( j ) + "_" + fileName
		j = j + 1
	return newFileName

save_uploaded_files()

print_html()
