require 'cgi'
require 'rexml/document'
require 'RMagick'
require 'rvg/rvg'

#This variable specifies relative path to the folder, where the gallery with uploaded files is located.
#Do not forget about the slash in the end of the folder name.
$galleryPath = "../Gallery/"

def print_html()
	print "Content-Type: text/html\r\n\r\n"
	print "\r\n"
end

def save_uploaded_files()
	$absGalleryPath = File.expand_path($galleryPath)
	absThumbnailsPath = File.join($absGalleryPath, "Thumbnails")

	#First of all, clear files and data uploaded at previous time.
	
	#Delete source files.		
	Dir.foreach($absGalleryPath) {|fileName|
		filePath = File.join($absGalleryPath, fileName)
		if File.ftype(filePath) == "file" then
			File.delete(filePath)
		end
	}

	#Delete thumbnails
	Dir.foreach(absThumbnailsPath) {|fileName|
		filePath = File.join(absThumbnailsPath, fileName)
		if File.ftype(filePath) == "file" then
			File.delete(filePath)
		end
	}

	#NOTE: If you do not want to delete previously uploaded files, just 
	#remove or comment out the code above.


	#Create XML file which will keep information about files (image dimensions, description, etc). 
	#XML is used solely for brevity. In real-life application most likely you will use database instead.
	descriptions = REXML::Document.new 
	filesElem = descriptions.add_element("files")

	cgi = CGI.new()

	#Get total number of uploaded files (all files are uploaded in a single package).
	fileCount = cgi.params["FileCount"].first.read

	#Iterate through uploaded data and save the original file, thumbnail, and description.
	for i in 1..fileCount.to_i
		#Get source file and save it to disk.
		sourceFile = cgi.params["SourceFile_" + i.to_s].first
		fileName = get_safe_file_name(sourceFile.original_filename)
		sourceFileTargetPath = File.join($absGalleryPath, fileName)
		file = File.open(sourceFileTargetPath.untaint, 'wb')
		file << sourceFile.read
		file.close
			
		#In this demo the following imaging operations are applied:
		#
		#  - If the user rotates the image in Image Uploader, rotate the original file.
		#  - Add a border around the image.
		sourceImage = Magick::Image.read(sourceFileTargetPath).first
		
		#Check if user rotated the image and if yes, what is the angle.
		angle = Integer(cgi.params["Angle_" + i.to_s].first.read)
				
		if angle != 0
			sourceImage.rotate!(angle)
		end
		
		#Add extra pixels to the image to be able to draw a border.		
		resultImage = Magick::Image.new(sourceImage.columns + 30, sourceImage.rows + 30)
		
		g = Magick::Draw.new
		
		#Fill the image with the border color.
		g.fill('#efefef')
		g.rectangle(0, 0, sourceImage.columns + 30, sourceImage.rows + 30)
				
		#Draw double border.
		g.stroke('#000000')
		g.stroke_width(1)
		g.rectangle(10, 10, sourceImage.columns + 19, sourceImage.rows + 19)
		g.rectangle(13, 13, sourceImage.columns + 16, sourceImage.rows + 16)
				
		g.draw resultImage

		#Copy the original image to the center of new image.
		resultImage.composite!(sourceImage, Magick::CenterGravity, Magick::OverCompositeOp)

		
		#Save the result file to disk
		resultImage.write(sourceFileTargetPath) {self.quality = 70}

		#Get first thumbnail (the single thumbnail in this code sample) and save it to disk.
		thumbnail1 = cgi.params["Thumbnail1_" + i.to_s].first
		thumbnail1TargetPath = File.join(absThumbnailsPath, fileName)
		File.open(thumbnail1TargetPath.untaint, 'wb') { |file| file << thumbnail1.read}

		#Save file info.
		fileElem = filesElem.add_element "file"
		fileElem.attributes["name"] = fileName
		fileElem.attributes["width"] = cgi.params["Width_" + i.to_s].first.read
		fileElem.attributes["height"] = cgi.params["Height_" + i.to_s].first.read
		fileElem.attributes["description"] = cgi.params["Description_" + i.to_s].first.read
	end

	descriptionsPath = File.join($absGalleryPath, "Descriptions.xml")
	File.open(descriptionsPath.untaint, 'w') { |file| descriptions.write file}
end

def get_safe_file_name(fileName)
	newFileName = File.basename(fileName)
	j = 1
	while FileTest.exist?(File.join($absGalleryPath, newFileName))
		newFileName = j.to_s + "_" + fileName
	end
	return newFileName
end

print_html()

save_uploaded_files()